<?php

namespace Drupal\server_beacon\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\server_beacon\Plugin\BeaconTransmitterInterface;

/**
 * Base interface for server beacon report configurations.
 */
interface ServerBeaconReportInterface extends ConfigEntityInterface {

  /**
   * Gets the machine name of the report.
   *
   * This is the name that identifies the report to the remote service stations
   * and ensures that the key data matches with the requested project.
   *
   * @return string
   *   Get the report name.
   */
  public function getName(): string;

  /**
   * Get the host information for the report station address.
   *
   * @return string
   *   The schema and host string of the station transmisison target.
   */
  public function reportHost(): string;

  /**
   * Get the address to transmit reports to.
   *
   * @return string
   *   The URL or address to send this report to.
   */
  public function reportTo(): string;

  /**
   * Get the labels of all the server beacons included in the report.
   *
   * @param bool $labels
   *   If true then return the label. If false, the the plugin ID is set as the
   *   returned array values.
   *
   * @return array<\Stringable|string>
   *   Get the list of beacon handler labels.
   */
  public function getBeaconTypes(bool $labels = FALSE): array;

  /**
   * Get the transmitter instance to use when sending this report.
   *
   * @return \Drupal\server_beacon\Plugin\BeaconTransmitterInterface|null
   *   The beacon transmitter handler if one is configured.
   */
  public function getTransmitter(): ?BeaconTransmitterInterface;

  /**
   * Get the server beacons that should send information with this report.
   *
   * @return \Drupal\server_beacon\Plugin\ServerBeaconInterface[]
   *   Get a list of server beacons attached to this report.
   */
  public function getBeacons(): array;

}
