<?php

namespace Drupal\server_beacon\Plugin;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\server_beacon\Attribute\ServerBeaconTransmitter;

/**
 * Default server beacon transmitter plugin manager.
 */
class BeaconTransmitterManager extends DefaultPluginManager implements BeaconTransmitterManagerInterface {

  /**
   * Creates a new instance of the BeaconTransmitterManager.
   *
   * @param \Traversable $namespaces
   *   The available module namespaces to search for plugin attributes.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   The cache backend to store server beacon definitions.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cacheBackend, ModuleHandlerInterface $moduleHandler) {
    parent::__construct(
      'Plugin/ServerBeacon/Transmitter',
      $namespaces,
      $moduleHandler,
      BeaconTransmitterInterface::class,
      ServerBeaconTransmitter::class
    );

    $this->alterInfo('server_beacon_transmitter');
    $this->setCacheBackend($cacheBackend, 'server_beacon_transmitter');
  }

  /**
   * {@inheritdoc}
   */
  public function getTransmitterOptions(): array {
    return array_column($this->getDefinitions(), 'label', 'id');
  }

}
