<?php

namespace Drupal\server_beacon\Plugin;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\server_beacon\Attribute\ServerBeacon;

/**
 * Default server beacon plugin manager.
 */
class ServerBeaconManager extends DefaultPluginManager implements ServerBeaconManagerInterface {

  /**
   * Creates a new instance of the ServerBeaconManager.
   *
   * @param \Traversable $namespaces
   *   The available module namespaces to search for plugin attributes.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheBackend
   *   The cache backend to store server beacon definitions.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cacheBackend, ModuleHandlerInterface $moduleHandler) {
    parent::__construct(
      'Plugin/ServerBeacon/Beacon',
      $namespaces,
      $moduleHandler,
      ServerBeaconInterface::class,
      ServerBeacon::class
    );

    $this->alterInfo('server_beacon');
    $this->setCacheBackend($cacheBackend, 'server_beacon');
  }

  /**
   * {@inheritdoc}
   */
  public function getBeaconOptions(): array {
    return array_column($this->getDefinitions(), 'label', 'id');
  }

}
