<?php

namespace Drupal\server_beacon;

use Drupal\server_beacon\Entity\ServerBeaconReportInterface;

/**
 * Interface for help class for transmitting reports to a server_station.
 */
interface ReporterInterface {

  /**
   * Create the report data for a ServerBeaconReport entity.
   *
   * Generates the data to be send by creating all the data from the service
   * beacons that are configured into a server beacon report.
   *
   * @param string|\Drupal\server_beacon\Entity\ServerBeaconReportInterface $report
   *   Either the ID of the report config entity, or the loaded entity.
   * @param string $environment
   *   The environment identifier for the report being sent.
   *
   * @return array
   *   The generated report data to transmit.
   */
  public function generateReport(string|ServerBeaconReportInterface $report, string $environment = ''): array;

  /**
   * Transmit a report to the target server station for the report.
   *
   * @param string|\Drupal\server_beacon\Entity\ServerBeaconReportInterface $report
   *   Either the ID of the report config entity, or the loaded entity.
   * @param string $environment
   *   The environment identifier for the report being sent.
   *
   * @return bool
   *   TRUE if the report sent, FALSE if there was an error.
   */
  public function transmitReport(string|ServerBeaconReportInterface $report, string $environment = ''): bool;

}
